pub fn gaussian_noise<T: SignalType>(
length: usize,
amplitude: f64,
) -> Result<Signal<T>>Expand description
Create a signal with Gaussian (normal) noise
Generates normally distributed random noise with given standard deviation. Mean is 0, and values are scaled by the amplitude parameter.
Returns an error if the amplitude is invalid (NaN, infinite, or <= 0).